==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ReportAggregationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ReportAggregationArgs.builder
import com.pulumi.azurenative.costmanagement.kotlin.enums.FunctionType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The aggregation expression to be used in the report.
 * @property function The name of the aggregation function to use.
 * @property name The name of the column to aggregate.
 */
public data class ReportAggregationArgs(
    public val function: Output<Either<String, FunctionType>>,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ReportAggregationArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ReportAggregationArgs =
        com.pulumi.azurenative.costmanagement.inputs.ReportAggregationArgs.builder()
            .function(
                function.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ReportAggregationArgs].
 */
@PulumiTagMarker
public class ReportAggregationArgsBuilder internal constructor() {
    private var function: Output<Either<String, FunctionType>>? = null

    private var name: Output<String>? = null

    /**
     * @param value The name of the aggregation function to use.
     */
    @JvmName("afmerrqhjobbwqlq")
    public suspend fun function(`value`: Output<Either<String, FunctionType>>) {
        this.function = value
    }

    /**
     * @param value The name of the column to aggregate.
     */
    @JvmName("wneanxenptgiqqaj")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The name of the aggregation function to use.
     */
    @JvmName("tiqgyfgiaxpvukwo")
    public suspend fun function(`value`: Either<String, FunctionType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.function = mapped
    }

    /**
     * @param value The name of the aggregation function to use.
     */
    @JvmName("jabfubchfjjvikcr")
    public fun function(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FunctionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.function = mapped
    }

    /**
     * @param value The name of the aggregation function to use.
     */
    @JvmName("vyvdvnkwfhiliheq")
    public fun function(`value`: FunctionType) {
        val toBeMapped = Either.ofRight<String, FunctionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.function = mapped
    }

    /**
     * @param value The name of the column to aggregate.
     */
    @JvmName("jmdcokwfjavlxtiv")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ReportAggregationArgs = ReportAggregationArgs(
        function = function ?: throw PulumiNullFieldException("function"),
        name = name ?: throw PulumiNullFieldException("name"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ReportAggregationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ReportAggregationArgs.builder
import com.pulumi.azurenative.costmanagement.kotlin.enums.FunctionType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The aggregation expression to be used in the report.
 * @property function The name of the aggregation function to use.
 * @property name The name of the column to aggregate.
 */
public data class ReportAggregationArgs(
    public val function: Output<Either<String, FunctionType>>,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ReportAggregationArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ReportAggregationArgs =
        com.pulumi.azurenative.costmanagement.inputs.ReportAggregationArgs.builder()
            .function(
                function.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ReportAggregationArgs].
 */
@PulumiTagMarker
public class ReportAggregationArgsBuilder internal constructor() {
    private var function: Output<Either<String, FunctionType>>? = null

    private var name: Output<String>? = null

    /**
     * @param value The name of the aggregation function to use.
     */
    @JvmName("hcvbueyuupmusndk")
    public suspend fun function(`value`: Output<Either<String, FunctionType>>) {
        this.function = value
    }

    /**
     * @param value The name of the column to aggregate.
     */
    @JvmName("nfyrjeyuiphcqbho")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The name of the aggregation function to use.
     */
    @JvmName("xcqcowwwqwgwcqrm")
    public suspend fun function(`value`: Either<String, FunctionType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.function = mapped
    }

    /**
     * @param value The name of the aggregation function to use.
     */
    @JvmName("fivkxnkqydofeewg")
    public fun function(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FunctionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.function = mapped
    }

    /**
     * @param value The name of the aggregation function to use.
     */
    @JvmName("aeqsmrnrywmoupwx")
    public fun function(`value`: FunctionType) {
        val toBeMapped = Either.ofRight<String, FunctionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.function = mapped
    }

    /**
     * @param value The name of the column to aggregate.
     */
    @JvmName("xmrpqckcjtrejpuh")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ReportAggregationArgs = ReportAggregationArgs(
        function = function ?: throw PulumiNullFieldException("function"),
        name = name ?: throw PulumiNullFieldException("name"),
    )
}
